@@ -5,7 +5,7 @@
 # Author    : Chris Jones
 # Email     : crj341@student.bham.ac.uk
 # Date      : 26/06/2020
-# Version   : 0.1.1
+# Version   : 0.1.2
 
 import  numpy                   as      np
 import  plotly.graph_objects    as      go
@@ -513,18 +513,22 @@ class AFM:
             _retract = self.retract[:,i]
             _z = self.z_position[:,i]
 
-            j = 0
+            try:
+                j = 0
 
-            while _approach[j] > 0:
-                j += 1
+                while _approach[j] > 0:
+                    j += 1
 
-            y = _z[j-1], _z[j]
-            x = _approach[j-1], _approach[j]
+                y = _z[j-1], _z[j]
+                x = _approach[j-1], _approach[j]
 
-            f = interp.interp1d(x,y)
-            intercept = f(0)
+                f = interp.interp1d(x,y)
+                intercept = f(0)
 
-            self.z_position[:,i] = self.z_position[:,i] - intercept
+                self.z_position[:,i] = self.z_position[:,i] - intercept
+
+            except:
+                print('WARNING: Could not locate contact point for curve number ', i, '. Consider checking baseline alignment.')
 
 
     def plot_adjusted(
@@ -608,6 +612,8 @@ class AFM:
         curve(s) to remove in the input <.delete_curve(i,j,k)>
         '''
 
+        i = 0
+
         for curve_number in args:
 
             self.approach = np.delete(self.approach, curve_number, axis = 1)
@@ -623,6 +629,11 @@ class AFM:
                 self.modulus = np.delete(self.modulus, curve_number, axis = 1)
             except:
                 pass
+
+            i += 1
+            for j in range(i, len(args)):
+                if args[j] > curve_number:
+                    args[j] = args[j] - 1
     
     def save_data(
         self,
